package com.ym.mec.web.controller;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.web.dal.entity.StudentRegistration;
import com.ym.mec.web.dal.page.StudentRegistrationQueryInfo;
import com.ym.mec.web.service.StudentRegistrationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@RequestMapping("studentRegistration")
@Api(tags = "学生报名信息服务")
@RestController
public class StudentRegistrationController extends BaseController {

    @Autowired
    private StudentRegistrationService studentRegistrationService;

    @ApiOperation(value = "新增学生报名信息")
    @PostMapping("/add")
    public Object add(StudentRegistration studentRegistration){
        Date date = new Date();
        studentRegistration.setCreateTime(date);
        studentRegistration.setUpdateTime(date);
        studentRegistrationService.insert(studentRegistration);
        return succeed();
    }

    @ApiOperation(value = "删除学生报名信息")
    @DeleteMapping("/del/{id}")
    public Object del(@ApiParam(value = "学生报名信息编号", required = true) @PathVariable("id") Long id){
        studentRegistrationService.delete(id);
        return succeed();
    }

    @ApiOperation(value = "修改学生报名信息")
    @PutMapping("/update")
    public Object update(StudentRegistration studentRegistration){
        studentRegistration.setUpdateTime(new Date());
        studentRegistrationService.update(studentRegistration);
        return succeed();
    }

    @ApiOperation(value = "分页查询学生乐团报名详情")
    @PostMapping("/queryStudentDetailPage")
    public Object queryStudentDetailPage(StudentRegistrationQueryInfo queryInfo){
        return succeed(studentRegistrationService.queryStudentDetailPage(queryInfo));
    }

    @ApiOperation(value = "批量调剂学生报名专业")
    @PutMapping("/batchUpdateSubject")
    public Object batchUpdateSubject(String userId,Integer subId){
        if(StringUtils.isEmpty(userId) || subId == null){
            return failed();
        }
        return succeed(studentRegistrationService.batchUpdateSubject(userId,subId));
    }
}
